#!/bin/sh

echo "post-install"

# App Central extend timeout, but the timeout seems be counted from post-install, not pre-install, so move "docker pull" to post-install.

docker pull campbellsoftwaresolutions/osticket:latest

echo "Completed docker pull"


CONTAINER_TEST=$(docker ps -a | grep osTicket | awk '{print $1}')

if [ ! -z $CONTAINER_TEST ]; then
	echo "osTicket container is there, remove it first."
	docker rm -f osTicket
fi

NAS_HOST=$AS_NAS_INET4_ADDR_0
if [ -z "$NAS_HOST" ]; then
    NAS_HOST=$AS_NAS_INET4_ADDR_1
fi

# get correct MariaDB port if it's changed by user.
MARIADB_PORT=3306
if [ -e /usr/local/AppCentral/mariadb/data/conf/asustor.conf ]; then
	MARIADB_PORT=$(cat /usr/local/AppCentral/mariadb/data/conf/asustor.conf | grep Port | awk '{print $3}')
fi


docker create -i -t --name=osTicket \
	-p 37080:80 -p 37090:9000 \
	-e MYSQL_HOST=$NAS_HOST \
	-e MYSQL_PORT=$MARIADB_PORT \
	-e MYSQL_DATABASE=osticketdocker \
	-e MYSQL_USER=osticketdocker \
	-e MYSQL_PASSWORD=osticketdocker \
	-v /etc/localtime:/etc/localtime:ro \
	-v /volume1/Docker/osTicket/data/upload/include/i18n:/data/upload/include/i18n:rw \
	-v /volume1/Docker/osTicket/data/upload/include/plugins:/data/upload/include/plugins:rw \
	-v /volume1/Docker/osTicket/nginx_log:/var/log/nginx:rw \
	--restart unless-stopped \
	campbellsoftwaresolutions/osticket:latest
	
docker start osTicket


case "$APKG_PKG_STATUS" in
	install)
		;;
	upgrade)
		oldim=$(docker images | grep campbellsoftwaresolutions/osticket | grep none | awk '{print $3}')
		echo $oldim
		
		if [ ! -z $oldim ]; then 
			docker rmi -f $oldim
		fi
		;;
	*)
		;;
esac

exit 0
